@@ -1,4 +1,4 @@
-ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
     # From print.survdiff
     if (length(x$n) == 1) {
         z <- sign(x$exp - x$obs) * sqrt(x$chisq)
@@ -30,13 +30,15 @@ ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE,
       digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
       valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style)
+      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup, calign = calign,
+         cvalign = cvalign, cstyle = cstyle, rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
+         rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
   return(obj)
 }
 
 # from xtable package
-ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
 
     cox <- x
     beta <- cox$coef
@@ -49,7 +51,9 @@ ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, fo
       digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
       valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style)
+      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup, calign = calign,
+         cvalign = cvalign, cstyle = cstyle, rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
+         rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
   return(obj)
 }
